@@ -164,6 +164,9 @@ INTERNALERROR_APIGWEXCEPTION = 'InternalError.ApigwException'
 # CAuth内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_CAUTHEXCEPTION = 'InternalError.CauthException'
 
+# CLB内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
+INTERNALERROR_CLBEXCEPTION = 'InternalError.ClbException'
+
 # oss内部请求错误，请稍后重试。若无法解决，请联系智能客服或提交工单。
 INTERNALERROR_OSSEXCEPTION = 'InternalError.OssException'
 
