@@ -137,6 +137,9 @@ INVALIDPARAMETER = 'InvalidParameter'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# Https证书与域名不匹配。
+INVALIDPARAMETERVALUE_CERTIFICATENOTMATCHDOMAIN = 'InvalidParameterValue.CertificateNotMatchDomain'
+
 # 域名在ICP黑名单内。
 INVALIDPARAMETERVALUE_DOMAININICPBLACKLIST = 'InvalidParameterValue.DomainInIcpBlacklist'
 
@@ -149,6 +152,9 @@ INVALIDPARAMETERVALUE_DUPLICATERS = 'InvalidParameterValue.DuplicateRS'
 # 监听器端口已存在。
 INVALIDPARAMETERVALUE_DUPLICATEDLISTENERPORT = 'InvalidParameterValue.DuplicatedListenerPort'
 
+# 无法同时开启所设置的特性。
+INVALIDPARAMETERVALUE_FEATURECONFLICT = 'InvalidParameterValue.FeatureConflict'
+
 # header黑名单限制。
 INVALIDPARAMETERVALUE_HITBLACKLIST = 'InvalidParameterValue.HitBlacklist'
 
@@ -176,6 +182,12 @@ INVALIDPARAMETERVALUE_INVALIDTAGS = 'InvalidParameterValue.InvalidTags'
 # 项目不属于该用户。
 INVALIDPARAMETERVALUE_PROJECTIDNOTBELONG = 'InvalidParameterValue.ProjectIdNotBelong'
 
+# 该通道组下无法支持该通道所需的特性。
+INVALIDPARAMETERVALUE_PROXYANDGROUPFEATURECONFLICT = 'InvalidParameterValue.ProxyAndGroupFeatureConflict'
+
+# 该地区不支持通道所设置的特性。
+INVALIDPARAMETERVALUE_PROXYANDREGIONFEATURECONFLICT = 'InvalidParameterValue.ProxyAndRegionFeatureConflict'
+
 # 源站不属于该用户。
 INVALIDPARAMETERVALUE_REALSERVERNOTBELONG = 'InvalidParameterValue.RealServerNotBelong'
 
@@ -197,9 +209,15 @@ RESOURCENOTFOUND = 'ResourceNotFound'
 # 资源不可用。
 RESOURCEUNAVAILABLE = 'ResourceUnavailable'
 
+# 账号下存在违规资源，详情请查看站内信或邮件。
+RESOURCEUNAVAILABLE_ACCOUNTVIOLATION = 'ResourceUnavailable.AccountViolation'
+
 # 未授权操作。
 UNAUTHORIZEDOPERATION = 'UnauthorizedOperation'
 
+# 跨境通道的联通带宽处于隔离中。
+UNAUTHORIZEDOPERATION_CROSSBORDERINISOLATING = 'UnauthorizedOperation.CrossBorderInIsolating'
+
 # 未知参数错误。
 UNKNOWNPARAMETER = 'UnknownParameter'
 
