@@ -35,7 +35,7 @@ class Device(AbstractModel):
         :type DeviceId: str
         :param IMEI: 该字段表示业务用户对应设备的**IMEI码**（国际移动设备识别码），该识别码可用于识别每一部独立的手机等移动通信设备，方便设备识别与管理。<br>备注：格式为**15-17位纯数字**。
         :type IMEI: str
-        :param IDFA: **iOS设备专用**，该字段表示业务用户对应的**IDFA**(广告标识符),这是由苹果公司提供的用于追踪用户的广告标识符，由一串16进制的32位数字和字母组成。<br>
+        :param IDFA: **iOS设备专用**，该字段表示业务用户对应的**IDFA**(广告标识符),这是由苹果公司提供的用于标识用户的广告标识符，由一串16进制的32位数字和字母组成。<br>
 备注：苹果公司自2021年iOS14更新后允许用户手动关闭或者开启IDFA，故此字符串标记有效性可能有所降低。
         :type IDFA: str
         :param IDFV: **iOS设备专用**，该字段表示业务用户对应的**IDFV**(应用开发商标识符),这是由苹果公司提供的用于标注应用开发商的标识符，由一串16进制的32位数字和字母组成，可被用于唯一标识设备。
@@ -460,12 +460,15 @@ class ObjectDetail(AbstractModel):
         :type Score: int
         :param Location: 该字段用于返回实体检测框的坐标位置（左上角xy坐标、长宽、旋转角度）以方便快速定位实体的相关信息。
         :type Location: :class:`tencentcloud.ims.v20201229.models.Location`
+        :param SubLabel: 该参数用于返回命中的实体二级标签。
+        :type SubLabel: str
         """
         self.Id = None
         self.Name = None
         self.Value = None
         self.Score = None
         self.Location = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -476,6 +479,7 @@ class ObjectDetail(AbstractModel):
         if params.get("Location") is not None:
             self.Location = Location()
             self.Location._deserialize(params.get("Location"))
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -618,6 +622,8 @@ class OcrTextDetail(AbstractModel):
         :type Location: :class:`tencentcloud.ims.v20201229.models.Location`
         :param Rate: 该参数用于返回OCR文本识别结果的置信度，取值在**0**（**置信度最低**）-**100**（**置信度最高**），越高代表对应图像越有可能是识别出的文字；如：*你好 99*，则表明OCR识别框内的文字大概率是”你好“。
         :type Rate: int
+        :param SubLabel: 该字段用于返回检测结果所对应的恶意二级标签。
+        :type SubLabel: str
         """
         self.Text = None
         self.Label = None
@@ -627,6 +633,7 @@ class OcrTextDetail(AbstractModel):
         self.Score = None
         self.Location = None
         self.Rate = None
+        self.SubLabel = None
 
 
     def _deserialize(self, params):
@@ -640,6 +647,7 @@ class OcrTextDetail(AbstractModel):
             self.Location = Location()
             self.Location._deserialize(params.get("Location"))
         self.Rate = params.get("Rate")
+        self.SubLabel = params.get("SubLabel")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
