@@ -49,6 +49,12 @@ class CreateJobConfigRequest(AbstractModel):
         :type JobManagerSpec: float
         :param TaskManagerSpec: TaskManager规格
         :type TaskManagerSpec: float
+        :param ClsLogsetId: CLS日志集ID
+        :type ClsLogsetId: str
+        :param ClsTopicId: CLS日志主题ID
+        :type ClsTopicId: str
+        :param LogCollectType: 日志采集类型 2：CLS；3：COS
+        :type LogCollectType: int
         """
         self.JobId = None
         self.EntrypointClass = None
@@ -62,6 +68,9 @@ class CreateJobConfigRequest(AbstractModel):
         self.LogCollect = None
         self.JobManagerSpec = None
         self.TaskManagerSpec = None
+        self.ClsLogsetId = None
+        self.ClsTopicId = None
+        self.LogCollectType = None
 
 
     def _deserialize(self, params):
@@ -87,6 +96,9 @@ class CreateJobConfigRequest(AbstractModel):
         self.LogCollect = params.get("LogCollect")
         self.JobManagerSpec = params.get("JobManagerSpec")
         self.TaskManagerSpec = params.get("TaskManagerSpec")
+        self.ClsLogsetId = params.get("ClsLogsetId")
+        self.ClsTopicId = params.get("ClsTopicId")
+        self.LogCollectType = params.get("LogCollectType")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -980,6 +992,12 @@ class JobConfig(AbstractModel):
         :param TaskManagerSpec: TaskManager规格
 注意：此字段可能返回 null，表示取不到有效值。
         :type TaskManagerSpec: float
+        :param ClsLogsetId: CLS日志集ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ClsLogsetId: str
+        :param ClsTopicId: CLS日志主题ID
+注意：此字段可能返回 null，表示取不到有效值。
+        :type ClsTopicId: str
         """
         self.JobId = None
         self.EntrypointClass = None
@@ -997,6 +1015,8 @@ class JobConfig(AbstractModel):
         self.MaxParallelism = None
         self.JobManagerSpec = None
         self.TaskManagerSpec = None
+        self.ClsLogsetId = None
+        self.ClsTopicId = None
 
 
     def _deserialize(self, params):
@@ -1026,6 +1046,8 @@ class JobConfig(AbstractModel):
         self.MaxParallelism = params.get("MaxParallelism")
         self.JobManagerSpec = params.get("JobManagerSpec")
         self.TaskManagerSpec = params.get("TaskManagerSpec")
+        self.ClsLogsetId = params.get("ClsLogsetId")
+        self.ClsTopicId = params.get("ClsTopicId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
@@ -1563,11 +1585,17 @@ class RunJobDescription(AbstractModel):
         :type StartMode: str
         :param JobConfigVersion: 当前作业的某个版本
         :type JobConfigVersion: int
+        :param SavepointPath: Savepoint路径
+        :type SavepointPath: str
+        :param SavepointId: Savepoint的Id
+        :type SavepointId: str
         """
         self.JobId = None
         self.RunType = None
         self.StartMode = None
         self.JobConfigVersion = None
+        self.SavepointPath = None
+        self.SavepointId = None
 
 
     def _deserialize(self, params):
@@ -1575,6 +1603,8 @@ class RunJobDescription(AbstractModel):
         self.RunType = params.get("RunType")
         self.StartMode = params.get("StartMode")
         self.JobConfigVersion = params.get("JobConfigVersion")
+        self.SavepointPath = params.get("SavepointPath")
+        self.SavepointId = params.get("SavepointId")
         memeber_set = set(params.keys())
         for name, value in vars(self).items():
             if name in memeber_set:
