@@ -218,9 +218,15 @@ INVALIDPARAMETERVALUE_CFSPARAMETERDUPLICATE = 'InvalidParameterValue.CfsParamete
 # cfs配置项取值与规范不符。
 INVALIDPARAMETERVALUE_CFSPARAMETERERROR = 'InvalidParameterValue.CfsParameterError'
 
+# cfs参数格式与规范不符。
+INVALIDPARAMETERVALUE_CFSSTRUCTIONERROR = 'InvalidParameterValue.CfsStructionError'
+
 # Ckafka传入错误。
 INVALIDPARAMETERVALUE_CKAFKA = 'InvalidParameterValue.Ckafka'
 
+# 运行函数时的参数传入有误。
+INVALIDPARAMETERVALUE_CLIENTCONTEXT = 'InvalidParameterValue.ClientContext'
+
 # Cls传入错误。
 INVALIDPARAMETERVALUE_CLS = 'InvalidParameterValue.Cls'
 
@@ -353,6 +359,9 @@ INVALIDPARAMETERVALUE_MEMORY = 'InvalidParameterValue.Memory'
 # MemorySize错误。
 INVALIDPARAMETERVALUE_MEMORYSIZE = 'InvalidParameterValue.MemorySize'
 
+# MinCapacity 参数传入错误。
+INVALIDPARAMETERVALUE_MINCAPACITY = 'InvalidParameterValue.MinCapacity'
+
 # Name参数传入错误。
 INVALIDPARAMETERVALUE_NAME = 'InvalidParameterValue.Name'
 
@@ -362,6 +371,12 @@ INVALIDPARAMETERVALUE_NAMESPACE = 'InvalidParameterValue.Namespace'
 # 规则不正确，Namespace为英文字母、数字、-_ 符号组成，长度30。
 INVALIDPARAMETERVALUE_NAMESPACEINVALID = 'InvalidParameterValue.NamespaceInvalid'
 
+# NodeSpec 参数传入错误。
+INVALIDPARAMETERVALUE_NODESPEC = 'InvalidParameterValue.NodeSpec'
+
+# NodeType 参数传入错误。
+INVALIDPARAMETERVALUE_NODETYPE = 'InvalidParameterValue.NodeType'
+
 # 偏移量不合法。
 INVALIDPARAMETERVALUE_OFFSET = 'InvalidParameterValue.Offset'
 
@@ -437,6 +452,9 @@ INVALIDPARAMETERVALUE_TEMPCOSOBJECTNAME = 'InvalidParameterValue.TempCosObjectNa
 # TraceEnable取值与规范不符，请修正后再试。
 INVALIDPARAMETERVALUE_TRACEENABLE = 'InvalidParameterValue.TraceEnable'
 
+# TrackingTarget 参数输入错误。
+INVALIDPARAMETERVALUE_TRACKINGTARGET = 'InvalidParameterValue.TrackingTarget'
+
 # TriggerCronConfig参数传入错误。
 INVALIDPARAMETERVALUE_TRIGGERCRONCONFIG = 'InvalidParameterValue.TriggerCronConfig'
 
@@ -596,6 +614,9 @@ RESOURCENOTFOUND_CDN = 'ResourceNotFound.Cdn'
 # 指定的cfs下未找到您所指定的挂载点。
 RESOURCENOTFOUND_CFSMOUNTINSNOTMATCH = 'ResourceNotFound.CfsMountInsNotMatch'
 
+# 检测cfs状态为不可用。
+RESOURCENOTFOUND_CFSSTATUSERROR = 'ResourceNotFound.CfsStatusError'
+
 # cfs与云函数所处vpc不一致。
 RESOURCENOTFOUND_CFSVPCNOTMATCH = 'ResourceNotFound.CfsVpcNotMatch'
 
@@ -722,5 +743,8 @@ UNSUPPORTEDOPERATION_REGION = 'UnsupportedOperation.Region'
 # Trigger操作不支持。
 UNSUPPORTEDOPERATION_TRIGGER = 'UnsupportedOperation.Trigger'
 
+# 指定的配置暂不支持，请修正后再试。
+UNSUPPORTEDOPERATION_UPDATEFUNCTIONEVENTINVOKECONFIG = 'UnsupportedOperation.UpdateFunctionEventInvokeConfig'
+
 # 指定的配置VpcConfig暂不支持。
 UNSUPPORTEDOPERATION_VPCCONFIG = 'UnsupportedOperation.VpcConfig'
