@@ -23,6 +23,9 @@ INVALIDPARAMETER_MALFORMED = 'InvalidParameter.Malformed'
 # 参数取值错误。
 INVALIDPARAMETERVALUE = 'InvalidParameterValue'
 
+# 不支持该参数值。
+INVALIDPARAMETERVALUE_NOTSUPPORTED = 'InvalidParameterValue.NotSupported'
+
 # 参数值过大。
 INVALIDPARAMETERVALUE_TOOLARGE = 'InvalidParameterValue.TooLarge'
 
@@ -34,3 +37,9 @@ INVALIDPARAMETERVALUE_TOOSMALL = 'InvalidParameterValue.TooSmall'
 
 # 集群不存在。
 RESOURCENOTFOUND_CLUSTERID = 'ResourceNotFound.ClusterId'
+
+# 无法找到ID对应的弹性伸缩启动配置。
+RESOURCENOTFOUND_LAUNCHCONFIGURATIONID = 'ResourceNotFound.LaunchConfigurationId'
+
+# 该伸缩组已绑定集群，请更换伸缩组。
+UNSUPPORTEDOPERATION_AUTOSCALINGGROUPALREADYBINDED = 'UnsupportedOperation.AutoScalingGroupAlreadyBinded'
