@@ -369,15 +369,15 @@ class DescribeCallDetailRequest(AbstractModel):
         :param DataType: 需查询的指标，不填则只返回用户列表，填all则返回所有指标。
 appCpu：APP CPU使用率；
 sysCpu：系统 CPU使用率；
-aBit：上/下行音频码率；
-aBlock：音频卡顿时长；
-bigvBit：上/下行视频码率；
+aBit：上/下行音频码率；单位：bps
+aBlock：音频卡顿时长；单位：ms
+bigvBit：上/下行视频码率；单位：bps
 bigvCapFps：视频采集帧率；
 bigvEncFps：视频发送帧率；
 bigvDecFps：渲染帧率；
-bigvBlock：视频卡顿时长；
-aLoss：上/下行音频丢包；
-bigvLoss：上/下行视频丢包；
+bigvBlock：视频卡顿时长；单位：ms
+aLoss：上/下行音频丢包率；
+bigvLoss：上/下行视频丢包率；
 bigvWidth：上/下行分辨率宽；
 bigvHeight：上/下行分辨率高
         :type DataType: list of str
@@ -650,200 +650,6 @@ class DescribePictureResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
-class DescribeRealtimeNetworkRequest(AbstractModel):
-    """DescribeRealtimeNetwork请求参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param StartTime: 查询开始时间，24小时内，本地unix时间戳（1588031999s）
-        :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
-        :type EndTime: int
-        :param SdkAppId: 用户sdkappid
-        :type SdkAppId: str
-        :param DataType: 需查询的数据类型
-sendLossRateRaw：上行丢包率
-recvLossRateRaw：下行丢包率
-        :type DataType: list of str
-        """
-        self.StartTime = None
-        self.EndTime = None
-        self.SdkAppId = None
-        self.DataType = None
-
-
-    def _deserialize(self, params):
-        self.StartTime = params.get("StartTime")
-        self.EndTime = params.get("EndTime")
-        self.SdkAppId = params.get("SdkAppId")
-        self.DataType = params.get("DataType")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class DescribeRealtimeNetworkResponse(AbstractModel):
-    """DescribeRealtimeNetwork返回参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param Data: 查询返回的数据
-        :type Data: list of RealtimeData
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
-        self.Data = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        if params.get("Data") is not None:
-            self.Data = []
-            for item in params.get("Data"):
-                obj = RealtimeData()
-                obj._deserialize(item)
-                self.Data.append(obj)
-        self.RequestId = params.get("RequestId")
-
-
-class DescribeRealtimeQualityRequest(AbstractModel):
-    """DescribeRealtimeQuality请求参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param StartTime: 查询开始时间，24小时内。本地unix时间戳（1588031999s）
-        :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
-        :type EndTime: int
-        :param SdkAppId: 用户sdkappid
-        :type SdkAppId: str
-        :param DataType: 查询的数据类型
-enterTotalSuccPercent：进房成功率
-fistFreamInSecRate：首帧秒开率
-blockPercent：视频卡顿率
-audioBlockPercent：音频卡顿率
-        :type DataType: list of str
-        """
-        self.StartTime = None
-        self.EndTime = None
-        self.SdkAppId = None
-        self.DataType = None
-
-
-    def _deserialize(self, params):
-        self.StartTime = params.get("StartTime")
-        self.EndTime = params.get("EndTime")
-        self.SdkAppId = params.get("SdkAppId")
-        self.DataType = params.get("DataType")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class DescribeRealtimeQualityResponse(AbstractModel):
-    """DescribeRealtimeQuality返回参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param Data: 返回的数据类型
-        :type Data: list of RealtimeData
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
-        self.Data = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        if params.get("Data") is not None:
-            self.Data = []
-            for item in params.get("Data"):
-                obj = RealtimeData()
-                obj._deserialize(item)
-                self.Data.append(obj)
-        self.RequestId = params.get("RequestId")
-
-
-class DescribeRealtimeScaleRequest(AbstractModel):
-    """DescribeRealtimeScale请求参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param StartTime: 查询开始时间，24小时内。本地unix时间戳（1588031999s）
-        :type StartTime: int
-        :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
-        :type EndTime: int
-        :param SdkAppId: 用户sdkappid
-        :type SdkAppId: str
-        :param DataType: 查询的数据类型
-UserNum：通话人数；
-RoomNum：房间数
-        :type DataType: list of str
-        """
-        self.StartTime = None
-        self.EndTime = None
-        self.SdkAppId = None
-        self.DataType = None
-
-
-    def _deserialize(self, params):
-        self.StartTime = params.get("StartTime")
-        self.EndTime = params.get("EndTime")
-        self.SdkAppId = params.get("SdkAppId")
-        self.DataType = params.get("DataType")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
-class DescribeRealtimeScaleResponse(AbstractModel):
-    """DescribeRealtimeScale返回参数结构体
-
-    """
-
-    def __init__(self):
-        r"""
-        :param Data: 返回的数据数组
-        :type Data: list of RealtimeData
-        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
-        :type RequestId: str
-        """
-        self.Data = None
-        self.RequestId = None
-
-
-    def _deserialize(self, params):
-        if params.get("Data") is not None:
-            self.Data = []
-            for item in params.get("Data"):
-                obj = RealtimeData()
-                obj._deserialize(item)
-                self.Data.append(obj)
-        self.RequestId = params.get("RequestId")
-
-
 class DescribeRecordStatisticRequest(AbstractModel):
     """DescribeRecordStatistic请求参数结构体
 
@@ -1830,40 +1636,6 @@ class QualityData(AbstractModel):
         
 
 
-class RealtimeData(AbstractModel):
-    """查询秒级监控返回的数据
-
-    """
-
-    def __init__(self):
-        r"""
-        :param Content: 返回的数据
-注意：此字段可能返回 null，表示取不到有效值。
-        :type Content: list of TimeValue
-        :param DataType: 数据类型字段
-        :type DataType: str
-        """
-        self.Content = None
-        self.DataType = None
-
-
-    def _deserialize(self, params):
-        if params.get("Content") is not None:
-            self.Content = []
-            for item in params.get("Content"):
-                obj = TimeValue()
-                obj._deserialize(item)
-                self.Content.append(obj)
-        self.DataType = params.get("DataType")
-        memeber_set = set(params.keys())
-        for name, value in vars(self).items():
-            if name in memeber_set:
-                memeber_set.remove(name)
-        if len(memeber_set) > 0:
-            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
-        
-
-
 class RecordUsage(AbstractModel):
     """录制的使用信息。
 
